import {Card, CardActions, CardContent, CardHeader, Grid, IconButton, CardMedia} from "@mui/material";
import {Link} from "react-router-dom";
import {PRODUCT_VIEW} from "../../../../constants/routes";
import ArrowForwardIosIcon from '@mui/icons-material/ArrowForwardIos';
import imageNotAvailable from '../../../../assets/images/image_not_available.png';
import {uploadUrl} from "../../../../constants/config";
import PropTypes from 'prop-types';

/**
 * @param {String} id
 * @param {Number} price
 * @param {String} title
 * @param {String} image
 * @returns {JSX.Element}
 * @constructor
 */
const ProductItem = ({id, price, title, image}) => {
    const imagePath = image
        ? uploadUrl + '/' + image
        : imageNotAvailable;

    return (
        <Grid item xs={12} sm={12} md={6} lg={4}>
            <Card>
                <CardHeader title={title}/>
                <CardContent>
                    <CardMedia
                        image={imagePath}
                        title={title}
                        sx={{maxWidth:200, height: 200}}
                    />
                    <strong style={{marginLeft: '10px'}}>
                        Price: {price} KZT
                    </strong>
                </CardContent>
                <CardActions>
                    <IconButton component={Link} to={PRODUCT_VIEW.replace(':id', id)}>
                        <ArrowForwardIosIcon/>
                    </IconButton>
                </CardActions>
            </Card>
        </Grid>
    );
};

ProductItem.propTypes = {
    id: PropTypes.string.isRequired,
    title: PropTypes.string.isRequired,
    price: PropTypes.number.isRequired,
    image: PropTypes.string
};

export default ProductItem;
