import {configureStore} from "@reduxjs/toolkit";
import usersReducer from "./services/usersSlice";
import productsReducer from "./services/productsSlice";
import categoriesReducer from "./services/categoriesSlice";

const localStorageMiddleware = ({getState}) => next => action => {
    const result = next(action);
    if (getState().usersState.user) {
        localStorage.setItem('user', JSON.stringify(getState().usersState.user));
    } else {
        localStorage.removeItem('user');
    }
    return result;
};

const reHydrateStore = () => {
    const userLocalStorage = localStorage.getItem('user');

    if (userLocalStorage !== null || userLocalStorage !== 'null' || userLocalStorage !== '') {
        return {
            usersState: {
                user: JSON.parse(localStorage.getItem('user'))
            }
        };
    }

    return undefined;
};

const store = configureStore({
    reducer: {
        usersState: usersReducer,
        productsState: productsReducer,
        categoriesState: categoriesReducer,
    },
    preloadedState: reHydrateStore(),
    middleware: getDefaultMiddleware => getDefaultMiddleware().concat(localStorageMiddleware)
});

export default store;
